extract_ndarray_shape

Function extract_ndarray_shape 

pub fn extract_ndarray_shape(schema: &Schema) -> ArrowResult<Vec<usize>>
Extract ndarray shape from an Arrow schema’s metadata

This is the inverse of ndarray_shape_schema.

Returns

The shape as a vector of dimension sizes, or an error if the metadata is missing or malformed.