pub struct BitVec { /* private fields */ }Expand description
A compact bit vector.
Bits are stored in u64 chunks. The bit at logical index i lives in
chunk i / 64 at bit position i % 64.
Implementations
Sourceimpl BitVec
impl BitVec
Sourcepub fn new(n_bits: usize) -> Self
pub fn new(n_bits: usize) -> Self
Creates a new BitVec of n_bits bits, all initialised to false.
Sourcepub fn all_ones(n_bits: usize) -> Self
pub fn all_ones(n_bits: usize) -> Self
Creates a BitVec of n_bits bits, all initialised to true.
Sourcepub fn get(&self, i: usize) -> bool
pub fn get(&self, i: usize) -> bool
Returns the value of bit i.
Returns false for out-of-range indices (does not panic).
Sourcepub fn count_ones(&self) -> usize
pub fn count_ones(&self) -> usize
Returns the number of bits set to 1.
Sourcepub fn count_zeros(&self) -> usize
pub fn count_zeros(&self) -> usize
Returns the number of bits set to 0.
Sourcepub fn iter_ones(&self) -> IterOnes<'_> ⓘ
pub fn iter_ones(&self) -> IterOnes<'_> ⓘ
Returns an iterator over the indices of all 1-bits in ascending order.
Sourcepub fn iter_zeros(&self) -> impl Iterator<Item = usize> + '_
pub fn iter_zeros(&self) -> impl Iterator<Item = usize> + '_
Returns an iterator over the indices of all 0-bits in ascending order.
Sourcepub fn and_assign(&mut self, other: &BitVec)
pub fn and_assign(&mut self, other: &BitVec)
self &= other. Panics if the bit-widths differ.
Sourcepub fn xor_assign(&mut self, other: &BitVec)
pub fn xor_assign(&mut self, other: &BitVec)
self ^= other. Panics if the bit-widths differ.
Sourcepub fn and(&self, other: &BitVec) -> BitVec
pub fn and(&self, other: &BitVec) -> BitVec
Returns self & other. Panics if the bit-widths differ.
Sourcepub fn or(&self, other: &BitVec) -> BitVec
pub fn or(&self, other: &BitVec) -> BitVec
Returns self | other. Panics if the bit-widths differ.