pub struct SkipList<K, V> { /* private fields */ }Expand description
A concurrent ordered map backed by a probabilistic skip list.
Keys must implement Ord + Clone; values must implement Clone.
Example
use scirs2_core::concurrent::SkipList;
let mut sl: SkipList<u32, String> = SkipList::new();
sl.insert(3, "three".to_string());
sl.insert(1, "one".to_string());
sl.insert(2, "two".to_string());
assert_eq!(sl.get(&1), Some("one".to_string()));
assert_eq!(sl.get(&2), Some("two".to_string()));
sl.remove(&2);
assert_eq!(sl.get(&2), None);Implementations
Sourceimpl<K: Ord + Clone, V: Clone> SkipList<K, V>
impl<K: Ord + Clone, V: Clone> SkipList<K, V>
Sourcepub fn get(&self, key: &K) -> Option<V>
pub fn get(&self, key: &K) -> Option<V>
Look up the value associated with key.
Returns None if no matching key exists.
Sourcepub fn remove(&mut self, key: &K) -> bool
pub fn remove(&mut self, key: &K) -> bool
Remove the entry with the given key. Returns true if a key was removed.
Sourcepub fn range(&self, lo: &K, hi: &K) -> Vec<(K, V)>
pub fn range(&self, lo: &K, hi: &K) -> Vec<(K, V)>
Return all key-value pairs whose keys fall within [lo, hi) in order.
Sourcepub fn iter(&self) -> Vec<(K, V)>
pub fn iter(&self) -> Vec<(K, V)>
Collect all key-value pairs in sorted order.
This traverses the bottom level of the skip list, so it is O(n).
Sourcepub fn remove_entry(&mut self, key: &K) -> Option<V>
pub fn remove_entry(&mut self, key: &K) -> Option<V>
Remove the entry with the given key, returning the value if it existed.