pub struct PriorityTaskQueue { /* private fields */ }Expand description
A bounded multi-priority task queue.
Tasks with Priority::High are dequeued before Priority::Normal,
which are dequeued before Priority::Low. Within a priority level
tasks are served FIFO.
Implementations
Sourceimpl PriorityTaskQueue
impl PriorityTaskQueue
Sourcepub fn submit<F>(&self, priority: Priority, f: F) -> CoreResult<()>
pub fn submit<F>(&self, priority: Priority, f: F) -> CoreResult<()>
Submit a task at the given priority.
Blocks if the queue is at capacity, or returns Err if the queue is
closed.
Sourcepub fn try_submit<F>(&self, priority: Priority, f: F) -> CoreResult<()>
pub fn try_submit<F>(&self, priority: Priority, f: F) -> CoreResult<()>
Try to submit without blocking. Returns Err if full or closed.
Sourcepub fn dequeue(&self) -> CoreResult<Option<Box<dyn FnOnce() + Send + 'static>>>
pub fn dequeue(&self) -> CoreResult<Option<Box<dyn FnOnce() + Send + 'static>>>
Block until a task is available, then return it.
Returns None when the queue is closed and drained.
Sourcepub fn try_dequeue(
&self,
) -> CoreResult<Option<Box<dyn FnOnce() + Send + 'static>>>
pub fn try_dequeue( &self, ) -> CoreResult<Option<Box<dyn FnOnce() + Send + 'static>>>
Try to dequeue without blocking. Returns None if empty.