pub struct TimeSeriesSplit {
pub n_splits: usize,
pub mode: TimeSeriesMode,
pub max_train_size: Option<usize>,
pub gap: usize,
}Expand description
Time series cross-validation splitter.
Provides train/test indices for time series data where the test set is always in the future relative to the training set.
Example
use scirs2_core::data_split::{TimeSeriesSplit, TimeSeriesMode};
let ts = TimeSeriesSplit::new(3, TimeSeriesMode::Expanding, None).expect("ts");
let splits: Vec<_> = ts.split(20);
assert_eq!(splits.len(), 3);
// Training sets grow: each has more data than the previousFields
n_splits: usizeNumber of splits
mode: TimeSeriesModeSplitting mode
max_train_size: Option<usize>Maximum training set size (only for Sliding mode)
gap: usizeGap between train and test sets
Implementations
Sourceimpl TimeSeriesSplit
impl TimeSeriesSplit
Sourcepub fn new(
n_splits: usize,
mode: TimeSeriesMode,
max_train_size: Option<usize>,
) -> CoreResult<Self>
pub fn new( n_splits: usize, mode: TimeSeriesMode, max_train_size: Option<usize>, ) -> CoreResult<Self>
Create a new TimeSeriesSplit.