pub struct SupportConfig {
pub github_issues_url: &'static str,
pub github_discussions_url: &'static str,
pub documentation_url: &'static str,
pub api_reference_url: &'static str,
pub email: &'static str,
pub response_time_hours: u32,
pub resolution_time_hours: Option<u32>,
pub tier: SupportTier,
pub security_email: &'static str,
pub changelog_url: &'static str,
}Expand description
Support channel configuration.
Contains all the information needed for users and customers to reach the SciRS2 support team.
Fields
github_issues_url: &'static strGitHub issues URL for bug reports and feature requests.
github_discussions_url: &'static strGitHub discussions URL for Q&A.
documentation_url: &'static strDocumentation website URL.
api_reference_url: &'static strAPI reference URL.
email: &'static strSupport email address.
response_time_hours: u32Target response time in hours for the current tier.
resolution_time_hours: Option<u32>Target resolution time in hours for the current tier.
tier: SupportTierCurrent support tier.
security_email: &'static strSecurity vulnerability reporting email.
changelog_url: &'static strChangelog / release notes URL.
Implementations
Sourceimpl SupportConfig
impl SupportConfig