pub struct MemoryTracker { /* private fields */ }Expand description
Thread-safe memory usage tracker.
Records allocations and deallocations so callers can inspect high-water-mark and current usage without relying on a system allocator hook.
Implementations
Sourceimpl MemoryTracker
impl MemoryTracker
Sourcepub fn record_allocation(&self, bytes: u64)
pub fn record_allocation(&self, bytes: u64)
Record an allocation of bytes bytes.
Sourcepub fn record_deallocation(&self, bytes: u64)
pub fn record_deallocation(&self, bytes: u64)
Record a deallocation of bytes bytes.
Sourcepub fn current_bytes(&self) -> u64
pub fn current_bytes(&self) -> u64
Get the current live bytes.
Sourcepub fn peak_bytes(&self) -> u64
pub fn peak_bytes(&self) -> u64
Get the peak (high-water mark) bytes.
Sourcepub fn report(&self) -> MemoryReport
pub fn report(&self) -> MemoryReport
Take a snapshot report.