AssignElem

Trait AssignElem 

pub trait AssignElem<T> {
    // Required method
    fn assign_elem(self, input: T);
}
A producer element that can be assigned to once

Required Methods

fn assign_elem(self, input: T)

Assign the value input to the element that self represents.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> AssignElem<T> for &Cell<T>

Assignable element, simply self.set(input).

Source

fn assign_elem(self, input: T)

Source

impl<T> AssignElem<T> for &mut MaybeUninit<T>

Assignable element, the item in the MaybeUninit is overwritten (prior value, if any, is not read or dropped).

Source

fn assign_elem(self, input: T)

Source

impl<T> AssignElem<T> for &mut T

Assignable element, simply *self = input.

Source

fn assign_elem(self, input: T)

Implementors

Source

impl<T> AssignElem<T> for &MathCell<T>

Assignable element, simply self.set(input).