Ix1

Function Ix1 

pub const fn Ix1(i0: usize) -> Dim<[usize; 1]>
Re-export essential ndarray types and macros for convenience Use ::ndarray to refer to the external crate directly Create a one-dimensional index