pub const fn Ix2(i0: usize, i1: usize) -> Dim<[usize; 2]>
Re-export essential ndarray types and macros for convenience Use ::ndarray to refer to the external crate directly Create a two-dimensional index