pub const fn Ix3(i0: usize, i1: usize, i2: usize) -> Dim<[usize; 3]>
Re-export essential ndarray types and macros for convenience Use ::ndarray to refer to the external crate directly Create a three-dimensional index