Ix5

Function Ix5 

pub const fn Ix5(
    i0: usize,
    i1: usize,
    i2: usize,
    i3: usize,
    i4: usize,
) -> Dim<[usize; 5]>
Re-export essential ndarray types and macros for convenience Use ::ndarray to refer to the external crate directly Create a five-dimensional index