pub struct ArbitraryFloat { /* private fields */ }Expand description
Arbitrary precision floating-point number backed by oxinum_float::DBig (Pure Rust).
DBig is a base-10 decimal big-float. The ArbitraryPrecisionContext stores
precision in bits (for API stability), but all oxinum calls receive the
equivalent decimal-digit count.
Implementations
Sourceimpl ArbitraryFloat
impl ArbitraryFloat
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new zero-valued arbitrary precision float with the default precision.
Sourcepub fn withprecision(prec: u32) -> CoreResult<Self>
pub fn withprecision(prec: u32) -> CoreResult<Self>
Create with a specific bit precision.
Sourcepub fn with_context(context: ArbitraryPrecisionContext) -> Self
pub fn with_context(context: ArbitraryPrecisionContext) -> Self
Create with a specific precision context.
Sourcepub fn from_f64_withprecision(v: f64, prec: u32) -> CoreResult<Self>
pub fn from_f64_withprecision(v: f64, prec: u32) -> CoreResult<Self>
Create from f64 with a specific bit precision.
Sourcepub fn from_strprec(s: &str, prec: u32) -> CoreResult<Self>
pub fn from_strprec(s: &str, prec: u32) -> CoreResult<Self>
Parse a decimal string with a specific bit precision.
Sourcepub fn decimalprecision(&self) -> u32
pub fn decimalprecision(&self) -> u32
Get the precision in decimal digits.
Sourcepub fn setprecision(&self, prec: u32) -> CoreResult<Self>
pub fn setprecision(&self, prec: u32) -> CoreResult<Self>
Return a new value rebound to the given bit precision.
Sourcepub fn is_finite(&self) -> bool
pub fn is_finite(&self) -> bool
Check if the value is finite (DBig is always finite — no NaN/infinity).
Sourcepub fn is_infinite(&self) -> bool
pub fn is_infinite(&self) -> bool
Check if the value is infinite (DBig has no infinity).
Sourcepub fn sqrt(&self) -> CoreResult<Self>
pub fn sqrt(&self) -> CoreResult<Self>
Square root.
Sourcepub fn ln(&self) -> CoreResult<Self>
pub fn ln(&self) -> CoreResult<Self>
Natural logarithm.
Sourcepub fn asin(&self) -> CoreResult<Self>
pub fn asin(&self) -> CoreResult<Self>
Arcsine.
Sourcepub fn acos(&self) -> CoreResult<Self>
pub fn acos(&self) -> CoreResult<Self>
Arccosine.
Sourcepub fn prec_2(prec: u32) -> CoreResult<Self>
pub fn prec_2(prec: u32) -> CoreResult<Self>
Compute π to the given bit precision.
Sourcepub fn prec_3(prec: u32) -> CoreResult<Self>
pub fn prec_3(prec: u32) -> CoreResult<Self>
Compute e (Euler’s number) to the given bit precision.
Sourcepub fn prec_4(prec: u32) -> CoreResult<Self>
pub fn prec_4(prec: u32) -> CoreResult<Self>
Compute ln(2) to the given bit precision.