pub fn pairwise_sum_array<T: Float>(values: &ArrayView1<'_, T>) -> TExpand description
Pairwise summation for an ndarray view.
Recursively splits the array and sums halves, achieving O(log n) error growth.
pub fn pairwise_sum_array<T: Float>(values: &ArrayView1<'_, T>) -> TPairwise summation for an ndarray view.
Recursively splits the array and sums halves, achieving O(log n) error growth.